import { File } from 'rxline/fs';
import { SimpleLine } from 'rxline';
/**
 *
 * Denotes a CODEDOC build process, during which
 * markdown files got built into HTML files.
 *
 */
export interface Build<ConfigType> {
    /**
     *
     * The configuration used for the build.
     *
     */
    config: ConfigType;
    /**
     *
     * Whether or not the build was a partial or full-build
     *
     */
    partial: boolean;
    /**
     *
     * The line of source files (i.e. markdown files) used for this build.
     *
     */
    source: SimpleLine<File<undefined>>;
    /**
     *
     * The list of built files (i.e. HTML files) generated by this build.
     *
     */
    built: File<string>[];
}
/**
 *
 * Denotes a function that should be executed after each build.
 *
 */
export declare type AfterBuild<ConfigType> = (build: Build<ConfigType>) => void | Promise<void>;
